@@ -4,7 +4,7 @@ import importlib.util
 
 KEY = None
 
-CONFIG_DIR = user_config_dir(appname="smsgateway", appauthor="craeckie")
+CONFIG_DIR = os.getenv('CONFIG_DIR', default=user_config_dir(appname="smsgateway", appauthor="craeckie"))
 if not os.path.exists(CONFIG_DIR):
     os.mkdir(CONFIG_DIR)
 
